from queue import Queue
from typing import Dict, List, Optional, Tuple

from loguru import logger
from pydantic import BaseModel


class Vertex(BaseModel):
    id: str
    color: Optional[int]
    edges: Optional[set]


class ColoringProblemBFSSolution:

    def __init__(self, vertexes: List[Vertex]):
        self._vertexes = vertexes
        self._is_solvable = True

    def bfs(self, m=2) -> None:
        m -= 1
        n = len(self._vertexes)
        visited = [False for _ in range(n)]
        max_color_count = 1

        for i in range(n):
            if not visited[i]:
                visited[i] = True
                q = Queue()
                q.put(i)

                while not q.empty():
                    top = q.get()

                    for j in self._vertexes[top].edges:
                        if self._vertexes[top].color == self._vertexes[j].color:
                            self._vertexes[j].color += 1

                        max_color_count = max(max_color_count, max(self._vertexes[top].color, self._vertexes[j].color))
                        if max_color_count > m:
                            self._is_solvable = False
                            self._vertexes[j].color = 0

                        if not visited[j]:
                            visited[j] = True
                            q.put(j)

    def get_colored(self) -> Tuple[bool, Dict[str, int]]:
        colored = dict()
        for v in self._vertexes:
            colored.update({v.id: v.color})

        return self._is_solvable, colored


def reformat(graph: Dict[str, List]) -> List[Vertex]:
    vertex_idx_dic = dict()
    idx = 0
    for k in graph.keys():
        vertex_idx_dic.update({k: idx})
        idx += 1

    vertexes = list()
    for v, edges in graph.items():
        edges = [vertex_idx_dic[item] for item in edges]
        vertexes.append(Vertex(id=v, color=0, edges=set(edges)))

    return vertexes


@logger.catch()
async def get_graph_coloring(graph: Dict[str, List]) -> Tuple[bool, Dict[str, int]]:
    vertexes = reformat(graph)
    solution = ColoringProblemBFSSolution(vertexes)
    solution.bfs()

    return solution.get_colored()
